summaryrefslogtreecommitdiffstats
path: root/kicker/applets
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 01:02:02 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 01:02:02 -0600
commitde7e5867a65e0a46f1388e3e50bc7eeddd1aecbf (patch)
treedbb3152c372f8620f9290137d461f3d9f9eba1cb /kicker/applets
parent936d3cec490c13f2c5f7dd14f5e364fddaa6da71 (diff)
downloadtdebase-de7e5867a65e0a46f1388e3e50bc7eeddd1aecbf.tar.gz
tdebase-de7e5867a65e0a46f1388e3e50bc7eeddd1aecbf.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'kicker/applets')
-rw-r--r--kicker/applets/clock/Makefile.am2
-rw-r--r--kicker/applets/clock/clock.cpp8
-rw-r--r--kicker/applets/clock/clock.h2
-rw-r--r--kicker/applets/clock/init.cpp4
-rw-r--r--kicker/applets/clock/prefs.kcfgc2
-rw-r--r--kicker/applets/clock/zone.cpp2
-rw-r--r--kicker/applets/launcher/CMakeLists.txt4
-rw-r--r--kicker/applets/launcher/ChangeLog8
-rw-r--r--kicker/applets/launcher/Makefile.am10
-rw-r--r--kicker/applets/launcher/ToDo2
-rw-r--r--kicker/applets/launcher/configdlg.h2
-rw-r--r--kicker/applets/launcher/popularity.cpp2
-rw-r--r--kicker/applets/launcher/prefs.kcfgc2
-rw-r--r--kicker/applets/launcher/quictdelauncher.cpp (renamed from kicker/applets/launcher/quicklauncher.cpp)20
-rw-r--r--kicker/applets/launcher/quictdelauncher.desktop (renamed from kicker/applets/launcher/quicklauncher.desktop)0
-rw-r--r--kicker/applets/launcher/quictdelauncher.h (renamed from kicker/applets/launcher/quicklauncher.h)4
-rw-r--r--kicker/applets/lockout/lockout.cpp4
-rw-r--r--kicker/applets/media/mediaapplet.cpp2
-rw-r--r--kicker/applets/media/mediaapplet.h4
-rw-r--r--kicker/applets/media/mediumbutton.h2
-rw-r--r--kicker/applets/media/preferencesdialog.cpp2
-rw-r--r--kicker/applets/media/preferencesdialog.h2
-rw-r--r--kicker/applets/menu/menuapplet.cpp2
-rw-r--r--kicker/applets/minipager/Makefile.am2
-rw-r--r--kicker/applets/naughty/NaughtyApplet.cpp2
-rw-r--r--kicker/applets/run/CMakeLists.txt2
-rw-r--r--kicker/applets/run/runapplet.cpp2
-rw-r--r--kicker/applets/swallow/swallow.cpp2
-rw-r--r--kicker/applets/systemtray/Makefile.am2
-rw-r--r--kicker/applets/systemtray/systemtrayapplet.cpp2
-rw-r--r--kicker/applets/taskbar/Makefile.am2
-rw-r--r--kicker/applets/trash/trashapplet.cpp2
-rw-r--r--kicker/applets/trash/trashbutton.cpp2
-rw-r--r--kicker/applets/trash/trashbutton.h2
34 files changed, 57 insertions, 57 deletions
diff --git a/kicker/applets/clock/Makefile.am b/kicker/applets/clock/Makefile.am
index 15bde61cf..fbb8ec319 100644
--- a/kicker/applets/clock/Makefile.am
+++ b/kicker/applets/clock/Makefile.am
@@ -19,7 +19,7 @@ clock_panelapplet_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
clock_panelapplet_la_LIBADD = ../../libkicker/libkickermain.la $(LIB_TDEUI)
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/clockapplet clockapplet *.h -lqt -ltdecore -ltdeui -lkfile
+ kdoc -a -p -H -d $$HOME/web/src/clockapplet clockapplet *.h -lqt -ltdecore -ltdeui -ltdefile
messages: rc.cpp
$(XGETTEXT) *.cpp *.h -o $(podir)/clockapplet.pot
diff --git a/kicker/applets/clock/clock.cpp b/kicker/applets/clock/clock.cpp
index 35dccf148..f9dd63e9e 100644
--- a/kicker/applets/clock/clock.cpp
+++ b/kicker/applets/clock/clock.cpp
@@ -47,10 +47,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <klocale.h>
#include <kpopupmenu.h>
#include <kstringhandler.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
#include <kfontrequester.h>
#include <kglobalsettings.h>
-#include <kconfigdialogmanager.h>
+#include <tdeconfigdialogmanager.h>
#include <kcalendarsystem.h>
#include <kicontheme.h>
#include <kiconloader.h>
@@ -1518,12 +1518,12 @@ void ClockApplet::contextMenuActivated(int result)
proc << locate("exe", "tdesu");
proc << "--nonewdcop";
proc << TQString("%1 tde-clock.desktop --lang %2")
- .arg(locate("exe", "kcmshell"))
+ .arg(locate("exe", "tdecmshell"))
.arg(TDEGlobal::locale()->language());
proc.start(TDEProcess::DontCare);
break;
case 104:
- proc << locate("exe", "kcmshell");
+ proc << locate("exe", "tdecmshell");
proc << "tde-language.desktop";
proc.start(TDEProcess::DontCare);
break;
diff --git a/kicker/applets/clock/clock.h b/kicker/applets/clock/clock.h
index 9a80c24b6..34d73cf83 100644
--- a/kicker/applets/clock/clock.h
+++ b/kicker/applets/clock/clock.h
@@ -37,7 +37,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <dcopobject.h>
#include <kpanelapplet.h>
#include <kdirwatch.h>
-#include <kconfigdialog.h>
+#include <tdeconfigdialog.h>
#include <kickertip.h>
#include "settings.h"
diff --git a/kicker/applets/clock/init.cpp b/kicker/applets/clock/init.cpp
index 9b89da87d..8cf336866 100644
--- a/kicker/applets/clock/init.cpp
+++ b/kicker/applets/clock/init.cpp
@@ -47,10 +47,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <klocale.h>
#include <kpopupmenu.h>
#include <kstringhandler.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
#include <kfontrequester.h>
#include <kglobalsettings.h>
-#include <kconfigdialogmanager.h>
+#include <tdeconfigdialogmanager.h>
#include <kcalendarsystem.h>
#include <kicontheme.h>
#include <kiconloader.h>
diff --git a/kicker/applets/clock/prefs.kcfgc b/kicker/applets/clock/prefs.kcfgc
index 890209526..fff5e1cad 100644
--- a/kicker/applets/clock/prefs.kcfgc
+++ b/kicker/applets/clock/prefs.kcfgc
@@ -1,4 +1,4 @@
-# Code generation options for kconfig_compiler
+# Code generation options for tdeconfig_compiler
File=clockapplet.kcfg
ClassName=Prefs
Singleton=false
diff --git a/kicker/applets/clock/zone.cpp b/kicker/applets/clock/zone.cpp
index bf007c933..c43b76db1 100644
--- a/kicker/applets/clock/zone.cpp
+++ b/kicker/applets/clock/zone.cpp
@@ -28,7 +28,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include "zone.h"
#include <kcolorbutton.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kstandarddirs.h>
#include <kstringhandler.h>
diff --git a/kicker/applets/launcher/CMakeLists.txt b/kicker/applets/launcher/CMakeLists.txt
index bf5111658..c022762c0 100644
--- a/kicker/applets/launcher/CMakeLists.txt
+++ b/kicker/applets/launcher/CMakeLists.txt
@@ -26,7 +26,7 @@ link_directories(
##### other data ################################
-install( FILES quicklauncher.desktop DESTINATION ${DATA_INSTALL_DIR}/kicker/applets )
+install( FILES quictdelauncher.desktop DESTINATION ${DATA_INSTALL_DIR}/kicker/applets )
install( FILES launcherapplet.kcfg DESTINATION ${KCFG_INSTALL_DIR} )
@@ -37,7 +37,7 @@ install( FILES launcherapplet.kcfg DESTINATION ${KCFG_INSTALL_DIR} )
tde_add_kpart( launcher_panelapplet AUTOMOC
SOURCES
- quicklauncher.skel quicklauncher.cpp quickbutton.cpp
+ quictdelauncher.skel quictdelauncher.cpp quickbutton.cpp
quickaddappsmenu.cpp flowgridmanager.cpp popularity.cpp
configdlgbase.ui prefs.kcfgc configdlg.cpp
LINK
diff --git a/kicker/applets/launcher/ChangeLog b/kicker/applets/launcher/ChangeLog
index b86dbd7aa..1144a8c35 100644
--- a/kicker/applets/launcher/ChangeLog
+++ b/kicker/applets/launcher/ChangeLog
@@ -4,9 +4,9 @@
* Empty panel now has size>0, so user can still drop icons on it.
* Fixed gcc 3.4 incompatibilities in EasyVector
* Fixed Drag and Drop Bugs :
- * Crash when non-url dropped on quicklauncher
- * Crash panel button dropped on quicklauncher
- * Able to drop objects when quicklauncher is locked
+ * Crash when non-url dropped on quictdelauncher
+ * Crash panel button dropped on quictdelauncher
+ * Able to drop objects when quictdelauncher is locked
* Add application context menu now inserts new app at current location
2004-06-14 Dan Bullok <dan.kde@bullok.com>
@@ -28,7 +28,7 @@
* Spouts tons of debugging info to kdDebug (for now).
2004-06-12 Dan Bullok <dan.kde@bullok.com>
- * Fixed bug #75351: Tooltips change to filenames after rearranging applications in quicklauncher.
+ * Fixed bug #75351: Tooltips change to filenames after rearranging applications in quictdelauncher.
* Moved the URL->(menuID,service,kurl) functionality from the QuickButton constructor to its own class: QuickURL. Very similar code is used elsewhere in kicker, and should eventually be merged.
* Renamed some methods in QuickButton (getId -> menuId, getURL -> url) This matches the predominant KDE naming style.
* Groundwork laid for variable-sized buttons.
diff --git a/kicker/applets/launcher/Makefile.am b/kicker/applets/launcher/Makefile.am
index a0384df4f..1e586e0dd 100644
--- a/kicker/applets/launcher/Makefile.am
+++ b/kicker/applets/launcher/Makefile.am
@@ -3,13 +3,13 @@ INCLUDES = -I$(top_srcdir)/kicker/libkicker -I$(top_srcdir)/kicker/kicker/ui $(a
kde_module_LTLIBRARIES = launcher_panelapplet.la
-launcher_panelapplet_la_SOURCES = quicklauncher.skel quicklauncher.cpp quickbutton.cpp quickaddappsmenu.cpp flowgridmanager.cpp popularity.cpp configdlgbase.ui prefs.kcfgc configdlg.cpp
+launcher_panelapplet_la_SOURCES = quictdelauncher.skel quictdelauncher.cpp quickbutton.cpp quickaddappsmenu.cpp flowgridmanager.cpp popularity.cpp configdlgbase.ui prefs.kcfgc configdlg.cpp
METASOURCES = AUTO
-noinst_HEADERS = quicklauncher.h quickbutton.h quickaddappsmenu.h easyvector.h quickbuttongroup.h flowgridmanager.h popularity.h configdlg.h
+noinst_HEADERS = quictdelauncher.h quickbutton.h quickaddappsmenu.h easyvector.h quickbuttongroup.h flowgridmanager.h popularity.h configdlg.h
lnkdir = $(kde_datadir)/kicker/applets
-lnk_DATA = quicklauncher.desktop
+lnk_DATA = quictdelauncher.desktop
EXTRA_DIST = $(lnk_DATA)
@@ -21,7 +21,7 @@ launcher_panelapplet_la_LIBADD = ../../kicker/core/libkicker_core.la ../../kick
kde_kcfg_DATA = launcherapplet.kcfg
messages: rc.cpp
- $(XGETTEXT) *.cpp *.h -o $(podir)/quicklauncher.pot
+ $(XGETTEXT) *.cpp *.h -o $(podir)/quictdelauncher.pot
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/quicklauncher quicklauncher *.h -lqt -ltdecore -ltdeui
+ kdoc -a -p -H -d $$HOME/web/src/quictdelauncher quictdelauncher *.h -lqt -ltdecore -ltdeui
diff --git a/kicker/applets/launcher/ToDo b/kicker/applets/launcher/ToDo
index c7c852a36..1f3932b08 100644
--- a/kicker/applets/launcher/ToDo
+++ b/kicker/applets/launcher/ToDo
@@ -3,6 +3,6 @@ TODO:
x * Remove debugging code (makes everything slow).
* Tooltip or other popup to alert user that buttons are locked (with a "don't show this again" checkbox).
* Docs.
- * Use old quicklauncher config file if found. #77959
+ * Use old quictdelauncher config file if found. #77959
X * "Add application" context menu should add the new application at the index of the button that summoned the context menu.
X * Make sure to always have a little space to drop things on, even when there are no buttons.
diff --git a/kicker/applets/launcher/configdlg.h b/kicker/applets/launcher/configdlg.h
index e5fdbe34b..b96caf459 100644
--- a/kicker/applets/launcher/configdlg.h
+++ b/kicker/applets/launcher/configdlg.h
@@ -24,7 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#ifndef CONFIG_DLG_H
#define CONFIG_DLG_H
-#include <kconfigdialog.h>
+#include <tdeconfigdialog.h>
class ConfigDlgBase;
class Prefs;
diff --git a/kicker/applets/launcher/popularity.cpp b/kicker/applets/launcher/popularity.cpp
index a22a98c99..f38062e5b 100644
--- a/kicker/applets/launcher/popularity.cpp
+++ b/kicker/applets/launcher/popularity.cpp
@@ -26,7 +26,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <assert.h>
#include <algorithm>
#include <iterator>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <list>
#include <set>
diff --git a/kicker/applets/launcher/prefs.kcfgc b/kicker/applets/launcher/prefs.kcfgc
index 243e97868..8a605b327 100644
--- a/kicker/applets/launcher/prefs.kcfgc
+++ b/kicker/applets/launcher/prefs.kcfgc
@@ -1,4 +1,4 @@
-# Code generation options for kconfig_compiler
+# Code generation options for tdeconfig_compiler
File=launcherapplet.kcfg
ClassName=Prefs
Singleton=false
diff --git a/kicker/applets/launcher/quicklauncher.desktop b/kicker/applets/launcher/quictdelauncher.desktop
index 771dc687e..771dc687e 100644
--- a/kicker/applets/launcher/quicklauncher.desktop
+++ b/kicker/applets/launcher/quictdelauncher.desktop
diff --git a/kicker/applets/launcher/quicklauncher.h b/kicker/applets/launcher/quictdelauncher.h
index 2dadf6344..c6fe1d2bb 100644
--- a/kicker/applets/launcher/quicklauncher.h
+++ b/kicker/applets/launcher/quictdelauncher.h
@@ -21,8 +21,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
******************************************************************/
-#ifndef __quicklauncher_h__
-#define __quicklauncher_h__
+#ifndef __quictdelauncher_h__
+#define __quictdelauncher_h__
#include <dcopobject.h>
#include <tqimage.h>
diff --git a/kicker/applets/lockout/lockout.cpp b/kicker/applets/lockout/lockout.cpp
index 72652d74b..b55aae92d 100644
--- a/kicker/applets/lockout/lockout.cpp
+++ b/kicker/applets/lockout/lockout.cpp
@@ -250,7 +250,7 @@ bool Lockout::eventFilter( TQObject *o, TQEvent *e )
void Lockout::slotLockPrefs()
{
// Run the screensaver settings
- KRun::run( "kcmshell screensaver", KURL::List() );
+ KRun::run( "tdecmshell screensaver", KURL::List() );
}
void Lockout::slotTransparent()
@@ -266,7 +266,7 @@ void Lockout::slotTransparent()
void Lockout::slotLogoutPrefs()
{
// Run the logout settings.
- KRun::run( "kcmshell kcmsmserver", KURL::List() );
+ KRun::run( "tdecmshell kcmsmserver", KURL::List() );
}
void Lockout::slotIconChanged()
diff --git a/kicker/applets/media/mediaapplet.cpp b/kicker/applets/media/mediaapplet.cpp
index 527c92b62..f8a1ac630 100644
--- a/kicker/applets/media/mediaapplet.cpp
+++ b/kicker/applets/media/mediaapplet.cpp
@@ -19,7 +19,7 @@
#include <kglobal.h>
#include <klocale.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kapplication.h>
#include <kaboutdata.h>
#include <kaboutapplication.h>
diff --git a/kicker/applets/media/mediaapplet.h b/kicker/applets/media/mediaapplet.h
index 68d0b5d99..4c57b508d 100644
--- a/kicker/applets/media/mediaapplet.h
+++ b/kicker/applets/media/mediaapplet.h
@@ -26,9 +26,9 @@
#include <kpanelapplet.h>
#include <tqstring.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kurl.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
#include <kdirlister.h>
#include <tqptrlist.h>
diff --git a/kicker/applets/media/mediumbutton.h b/kicker/applets/media/mediumbutton.h
index 3fa31756a..5f6a2b80b 100644
--- a/kicker/applets/media/mediumbutton.h
+++ b/kicker/applets/media/mediumbutton.h
@@ -26,7 +26,7 @@
#include <tqpixmap.h>
#include <tqcursor.h>
#include <tqtimer.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
#include <kpanelapplet.h>
#include <kactioncollection.h>
diff --git a/kicker/applets/media/preferencesdialog.cpp b/kicker/applets/media/preferencesdialog.cpp
index bf8234fe5..f53381a10 100644
--- a/kicker/applets/media/preferencesdialog.cpp
+++ b/kicker/applets/media/preferencesdialog.cpp
@@ -24,7 +24,7 @@
#include <tqvbox.h>
#include <tqwhatsthis.h>
#include <klistview.h>
-#include <kfiledetailview.h>
+#include <tdefiledetailview.h>
class MediumTypeItem : public TQCheckListItem
{
diff --git a/kicker/applets/media/preferencesdialog.h b/kicker/applets/media/preferencesdialog.h
index e946f81de..f758d280b 100644
--- a/kicker/applets/media/preferencesdialog.h
+++ b/kicker/applets/media/preferencesdialog.h
@@ -22,7 +22,7 @@
#include <tqwidget.h>
#include <kdialogbase.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
/**
*@author ervin
diff --git a/kicker/applets/menu/menuapplet.cpp b/kicker/applets/menu/menuapplet.cpp
index 732f5acdb..8a9f68095 100644
--- a/kicker/applets/menu/menuapplet.cpp
+++ b/kicker/applets/menu/menuapplet.cpp
@@ -31,7 +31,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqvariant.h> // avoid X11 #define's
#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kglobal.h>
#include <klocale.h>
diff --git a/kicker/applets/minipager/Makefile.am b/kicker/applets/minipager/Makefile.am
index 9320c30f5..f1009df41 100644
--- a/kicker/applets/minipager/Makefile.am
+++ b/kicker/applets/minipager/Makefile.am
@@ -22,4 +22,4 @@ messages: rc.cpp
$(XGETTEXT) *.cpp *.h -o $(podir)/kminipagerapplet.pot
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/kminipagerapplet kminipagerapplet *.h -lqt -ltdecore -ltdeui -lkfile
+ kdoc -a -p -H -d $$HOME/web/src/kminipagerapplet kminipagerapplet *.h -lqt -ltdecore -ltdeui -ltdefile
diff --git a/kicker/applets/naughty/NaughtyApplet.cpp b/kicker/applets/naughty/NaughtyApplet.cpp
index eb663814b..4e3332768 100644
--- a/kicker/applets/naughty/NaughtyApplet.cpp
+++ b/kicker/applets/naughty/NaughtyApplet.cpp
@@ -28,7 +28,7 @@
#include <kiconloader.h>
#include <kglobal.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kaboutapplication.h>
#include <kaboutdata.h>
#include <klocale.h>
diff --git a/kicker/applets/run/CMakeLists.txt b/kicker/applets/run/CMakeLists.txt
index 68c7c7c0c..0e1ca3960 100644
--- a/kicker/applets/run/CMakeLists.txt
+++ b/kicker/applets/run/CMakeLists.txt
@@ -29,6 +29,6 @@ install( FILES runapplet.desktop DESTINATION ${DATA_INSTALL_DIR}/kicker/applets
tde_add_kpart( run_panelapplet AUTOMOC
SOURCES runapplet.cpp
- LINK kio-shared
+ LINK tdeio-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kicker/applets/run/runapplet.cpp b/kicker/applets/run/runapplet.cpp
index f0069cae6..5f930190a 100644
--- a/kicker/applets/run/runapplet.cpp
+++ b/kicker/applets/run/runapplet.cpp
@@ -30,7 +30,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kapplication.h>
#include <kglobal.h>
#include <klocale.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kcombobox.h>
#include <kurifilter.h>
#include <kdialog.h>
diff --git a/kicker/applets/swallow/swallow.cpp b/kicker/applets/swallow/swallow.cpp
index 428d0bb7e..2f5000b72 100644
--- a/kicker/applets/swallow/swallow.cpp
+++ b/kicker/applets/swallow/swallow.cpp
@@ -25,7 +25,7 @@
#include <kapplication.h>
#include <kcmdlineargs.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <klocale.h>
#include <kmessagebox.h>
diff --git a/kicker/applets/systemtray/Makefile.am b/kicker/applets/systemtray/Makefile.am
index 2749c7391..3ba76ca5c 100644
--- a/kicker/applets/systemtray/Makefile.am
+++ b/kicker/applets/systemtray/Makefile.am
@@ -21,4 +21,4 @@ messages:
$(XGETTEXT) *.cpp *.h -o $(podir)/ksystemtrayapplet.pot
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/ksystemtrayapplet ksystemtrayapplet *.h -lqt -ltdecore -ltdeui -lkfile
+ kdoc -a -p -H -d $$HOME/web/src/ksystemtrayapplet ksystemtrayapplet *.h -lqt -ltdecore -ltdeui -ltdefile
diff --git a/kicker/applets/systemtray/systemtrayapplet.cpp b/kicker/applets/systemtray/systemtrayapplet.cpp
index 02f13df2b..835174f92 100644
--- a/kicker/applets/systemtray/systemtrayapplet.cpp
+++ b/kicker/applets/systemtray/systemtrayapplet.cpp
@@ -38,7 +38,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <dcopclient.h>
#include <kapplication.h>
#include <klocale.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kdebug.h>
#include <kglobal.h>
#include <krun.h>
diff --git a/kicker/applets/taskbar/Makefile.am b/kicker/applets/taskbar/Makefile.am
index 9f6914f8e..c1375230e 100644
--- a/kicker/applets/taskbar/Makefile.am
+++ b/kicker/applets/taskbar/Makefile.am
@@ -19,4 +19,4 @@ messages:
$(XGETTEXT) *.cpp *.h -o $(podir)/ktaskbarapplet.pot
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/ktaskbarapplet ktaskbarapplet *.h -lqt -ltdecore -ltdeui -lkfile
+ kdoc -a -p -H -d $$HOME/web/src/ktaskbarapplet ktaskbarapplet *.h -lqt -ltdecore -ltdeui -ltdefile
diff --git a/kicker/applets/trash/trashapplet.cpp b/kicker/applets/trash/trashapplet.cpp
index 6e1f11504..478ac01ec 100644
--- a/kicker/applets/trash/trashapplet.cpp
+++ b/kicker/applets/trash/trashapplet.cpp
@@ -19,7 +19,7 @@
#include <kglobal.h>
#include <klocale.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kapplication.h>
#include <kaboutdata.h>
#include <kaboutapplication.h>
diff --git a/kicker/applets/trash/trashbutton.cpp b/kicker/applets/trash/trashbutton.cpp
index 57904db43..1f45e1fb4 100644
--- a/kicker/applets/trash/trashbutton.cpp
+++ b/kicker/applets/trash/trashbutton.cpp
@@ -26,7 +26,7 @@
#include <krun.h>
#include <kpopupmenu.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
#include <konq_operations.h>
#include <konq_popupmenu.h>
diff --git a/kicker/applets/trash/trashbutton.h b/kicker/applets/trash/trashbutton.h
index 891e274c0..0ddad290e 100644
--- a/kicker/applets/trash/trashbutton.h
+++ b/kicker/applets/trash/trashbutton.h
@@ -26,7 +26,7 @@
#include <tqpixmap.h>
#include <tqcursor.h>
#include <tqtimer.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
#include <kpanelapplet.h>
#include <kactioncollection.h>
diff --git a/kicker/applets/launcher/quicklauncher.cpp b/kicker/applets/launcher/quictdelauncher.cpp
index e5658f1cb..87ac35387 100644
--- a/kicker/applets/launcher/quicklauncher.cpp
+++ b/kicker/applets/launcher/quictdelauncher.cpp
@@ -38,7 +38,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <klocale.h>
#include <kmessagebox.h>
#include <knuminput.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <kstandarddirs.h>
#include <kurldrag.h>
#include <kdebug.h>
@@ -52,7 +52,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include "configdlg.h"
#include "popularity.h"
-#include "quicklauncher.h"
+#include "quictdelauncher.h"
#include "quickbutton.h"
#include "quickaddappsmenu.h"
#include "quickbuttongroup.h"
@@ -71,10 +71,10 @@ extern "C"
{
KDE_EXPORT KPanelApplet* init(TQWidget *parent, const TQString& configFile)
{
- TDEGlobal::locale()->insertCatalogue("quicklauncher");
+ TDEGlobal::locale()->insertCatalogue("quictdelauncher");
return new QuickLauncher(configFile, KPanelApplet::Normal,
KPanelApplet::Preferences,
- parent, "quicklauncher");
+ parent, "quictdelauncher");
}
}
@@ -107,7 +107,7 @@ QuickLauncher::QuickLauncher(const TQString& configFile, Type type, int actions,
m_oldButtons = 0;
m_dragButtons = 0;
- m_configAction = new KAction(i18n("Configure Quicklauncher..."), "configure", KShortcut(),
+ m_configAction = new KAction(i18n("Configure Quictdelauncher..."), "configure", KShortcut(),
TQT_TQOBJECT(this), TQT_SLOT(slotConfigure()), TQT_TQOBJECT(this));
m_saveTimer = new TQTimer(this, "m_saveTimer");
@@ -135,7 +135,7 @@ QuickLauncher::QuickLauncher(const TQString& configFile, Type type, int actions,
"QuickLauncherApplet",
"serviceStartedByStorageId(TQString,TQString)",
false);
- kdDebug() << "Quicklauncher registered DCOP signal" << endl;
+ kdDebug() << "Quictdelauncher registered DCOP signal" << endl;
}
@@ -143,7 +143,7 @@ QuickLauncher::QuickLauncher(const TQString& configFile, Type type, int actions,
QuickLauncher::~QuickLauncher()
{
- TDEGlobal::locale()->removeCatalogue("quicklauncher");
+ TDEGlobal::locale()->removeCatalogue("quictdelauncher");
setCustomMenu(0);
delete m_popup;
delete m_appletPopup;
@@ -496,7 +496,7 @@ void QuickLauncher::addAppBeforeManually(TQString url, TQString sender)
void QuickLauncher::about()
{
- TDEAboutData about("quicklauncher", I18N_NOOP("Quick Launcher"), "2.0",
+ TDEAboutData about("quictdelauncher", I18N_NOOP("Quick Launcher"), "2.0",
I18N_NOOP("A simple application launcher"),
TDEAboutData::License_GPL_V2,
"(C) 2000 Bill Nagel\n(C) 2004 Dan Bullok\n(C) 2005 Fred Schaettgen");
@@ -949,7 +949,7 @@ void QuickLauncher::serviceStartedByStorageId(TQString /*starter*/, TQString sto
QuickURL url = QuickURL(locate("apps", service->desktopEntryPath()));
TQString desktopMenuId(url.menuId());
kdDebug() << "storageId=" << storageId << " desktopURL=" << desktopMenuId << endl;
// A service was started somwhere else. If the quicklauncher contains
// this service too, we flash the icon
QuickButton *startedButton = 0;
std::set<TQString> buttonIdSet;
@@ -1127,4 +1127,4 @@ void QuickLauncher::positionChange(Position)
}
-#include "quicklauncher.moc"
+#include "quictdelauncher.moc"
@@ -949,7 +949,7 @@ void QuickLauncher::serviceStartedByStorageId(TQString /*starter*/, TQString sto
TQString desktopMenuId(url.menuId());
kdDebug() << "storageId=" << storageId << " desktopURL=" << desktopMenuId << endl;
- // A service was started somwhere else. If the quicklauncher contains
+ // A service was started somwhere else. If the quictdelauncher contains
// this service too, we flash the icon
QuickButton *startedButton = 0;